==> ebean-core-12.15.1.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module io.ebean.core {
    /* transitive */ requires io.ebean.api;
    /* transitive */ requires io.ebean.migration.auto;
    /* transitive */ requires io.ebean.xmapping.api;
    /* transitive */ requires io.ebean.core.type;
    /* transitive */ requires io.ebean.ddl.runner;
    /* transitive */ requires org.antlr.antlr4.runtime;
    requires io.avaje.classpath.scanner;
    requires io.ebean.types;
    requires org.slf4j;
    /* static phase */ requires io.avaje.jsr305x;
    /* static phase */ requires com.fasterxml.jackson.core;
    /* static phase */ requires com.fasterxml.jackson.databind;
    /* static phase */ requires jakarta.validation;
    /* static phase */ requires java.transaction;
    /* static phase */ requires java.naming;
    /* static phase */ requires java.validation;
    /* static phase */ requires org.postgresql.jdbc;
    /* static phase */ requires joda.time;

    exports io.ebeaninternal.api;
    exports io.ebeaninternal.server.cache;
    exports io.ebeaninternal.server.deploy;
    exports io.ebeaninternal.server.deploy.visitor;
    exports io.ebeaninternal.server.el to io.ebean.autotune;
    exports io.ebeaninternal.server.autotune to io.ebean.autotune;
    exports io.ebeaninternal.server.querydefn to io.ebean.autotune, io.ebean.querybean;
    exports io.ebeaninternal.server.type to io.ebean.postgis;
    exports io.ebeaninternal.server.util to io.ebean.querybean;
    exports io.ebeaninternal.server.expression to io.ebean.querybean;

    provides MetricFactory with DMetricFactory;
    provides SpiContainerFactory with DContainerFactory;
    provides SpiFetchGroupService with DFetchGroupService;
    provides SpiJsonService with DJsonService;
    provides SpiProfileLocationFactory with DProfileLocationFactory;
    provides SpiRawSqlService with DRawSqlService;

}

==> ebean-core-12.16.1.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module io.ebean.core {
    /* transitive */ requires io.ebean.api;
    /* transitive */ requires io.ebean.migration.auto;
    /* transitive */ requires io.ebean.xmapping.api;
    /* transitive */ requires io.ebean.core.type;
    /* transitive */ requires io.ebean.ddl.runner;
    /* transitive */ requires org.antlr.antlr4.runtime;
    requires io.avaje.classpath.scanner;
    requires io.ebean.types;
    requires org.slf4j;
    /* static phase */ requires io.avaje.jsr305x;
    /* static phase */ requires com.fasterxml.jackson.core;
    /* static phase */ requires com.fasterxml.jackson.databind;
    /* static phase */ requires jakarta.validation;
    /* static phase */ requires java.transaction;
    /* static phase */ requires java.naming;
    /* static phase */ requires java.validation;
    /* static phase */ requires org.postgresql.jdbc;
    /* static phase */ requires joda.time;

    exports io.ebeaninternal.server.cache;
    exports io.ebeaninternal.api to io.ebean.ddl.generator, io.ebean.querybean, io.ebean.autotune, io.ebean.postgis, io.ebean.test;
    exports io.ebeaninternal.server.deploy to io.ebean.autotune, io.ebean.ddl.generator;
    exports io.ebeaninternal.server.deploy.id to io.ebean.ddl.generator;
    exports io.ebeaninternal.server.deploy.meta to io.ebean.ddl.generator;
    exports io.ebeaninternal.server.deploy.visitor to io.ebean.ddl.generator;
    exports io.ebeaninternal.server.el to io.ebean.autotune;
    exports io.ebeaninternal.server.autotune to io.ebean.autotune;
    exports io.ebeaninternal.server.querydefn to io.ebean.autotune, io.ebean.querybean;
    exports io.ebeaninternal.server.type to io.ebean.postgis;
    exports io.ebeaninternal.server.util to io.ebean.querybean;
    exports io.ebeaninternal.server.expression to io.ebean.querybean;

    provides MetricFactory with DMetricFactory;
    provides SpiContainerFactory with DContainerFactory;
    provides SpiFetchGroupService with DFetchGroupService;
    provides SpiJsonService with DJsonService;
    provides SpiProfileLocationFactory with DProfileLocationFactory;
    provides SpiRawSqlService with DRawSqlService;

}
